@@ -4,12 +4,10 @@
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef GRANTLEETHEME_COLORSCHEME_H
-#define GRANTLEETHEME_COLORSCHEME_H
+#pragma once
 
 namespace ColorScheme
 {
 void registerMetaType();
 }
 
-#endif // GRANTLEETHEME_COLORSCHEME_H
